
Class DCM
=========

.. autoclass:: ahrs.common.dcm.DCM

**Attributes**

.. toctree::
    :maxdepth: 2
    :titlesonly:

    classDCM.I
    classDCM.inv
    classDCM.det
    classDCM.determinant
    classDCM.fro
    classDCM.frobenius
    classDCM.log
    classDCM.adj
    classDCM.adjugate

**Methods**

.. toctree::
    :maxdepth: 2
    :titlesonly:

    classDCM.to_axisangle
    classDCM.to_axang
    classDCM.from_axisangle
    classDCM.from_axang
    classDCM.from_quaternion
    classDCM.from_q
    classDCM.to_quaternion
    classDCM.to_q
    classDCM.to_angles
    classDCM.to_rpy
    classDCM.ode
